# The Offshift Ecosystem Whitepaper
*An On-Chain Ecosystem For Layer 1 Private DeFi Applications*

*NOTE: The Offshift Ecosystem Whitepaper is a living document whose contents may be modifed by Offshift Core in response to ongoing research.*

## Table of Contents

**I.**		[Abstract](#i.-abstract)

**II.**		[Introduction: Market Analysis](#ii.-introduction:-market-analysis)

**III.**	[PriFi (Private Decentralized Finance) and the PriFi Standard](#iii.-prifi-and-the-prifi-standard)

**IV.**		[Ecosystem Features and Dynamics](#iv.-ecosystem-features-and-dynamics)

	A. [On-Chain Privacy Solutions](#a.-on-chain-privacy-solutions)

	B. [Chainlink Oracles for On-Chain Asset Diversity](#b.-chainlink-oracles-for-on-chain-asset-diversity)

	C. [Seamless Shifting to Replace Collateral Management](#c.-seamless-shifting-to-replace-collateral-management)

	D. [Hardcoded Integrity](#d.-hardcoded-integrity)

**V.**		[Platform Tokenomics: Utility and Incentives](#v.-platform-tokenomics:-utility-and-incentives)

			A. [Shifting with the Burn-and-Mint Mechanism](#a.-shifting-with-the-burn-and-mint-mechanism)

			B. [Reward Incentives: Staking Rewards](#b.-reward-incentives:-staking-rewards)

**VI.**		[Fundraising Model and Token Metrics](#vi.-fundraising-model-&-token-metrics)

			A. [Capital Raise](#a.-capital-raise)

			B. [Token Allocations](#b.-token-allocations)

			C. [High-Integrity Tokenomic Measures](#c.-high-integrity-tokenomic-measures)

			D. [Token Emission Schedule](#d.-token-emission-schedule)

**VII.**	[Long-Term Vision: A Privacy-Centric DeFi Ecosystem](#vii.-long-term-vision:-a-privacy-centric-defi-ecosystem)

**VIII.**	[Resources](#viii.-resources)

**IX.**		[Disclaimer](#ix.-disclaimer)




# I. Abstract

Within the crypto space, the 2020s have quickly proven to be the decade of DeFi (Decentralized Finance). However, growing interest in DeFi has relegated cryptocurrency’s privacy-centric origins to the sidelines. Users now must choose between cutting-edge platforms designed to maximize yields and standalone privacy applications whose infrastructure and assets permit limited integration potential in other protocols, thereby limiting yield generation. Others still incorporate elements of centralization by relying on rollups and other Layer 2s for obfuscation and off-chain computation. In short, protecting privacy now comes at the expense of either putting capital to work, or critical infrastructure components that are needed to support decentralized systems. There exists substantial, untapped demand in Ethereum’s DeFi ecosystem for a technology solution that eliminates the financial tradeoffs between privacy and DeFi while remaining true to cryptocurrency’s founding principle of decentralization.

The Offshift Ecosystem is a fully on-chain, non-custodial platform designed to provide protections for user privacy without compromising yield potential or decentralization. The Offshift Ecosystem is developed by Offshift Core, the ecosystem's core development team, and powered by XFT, a public ERC20 token that confers access to ecosystem applications via Burn-and-Mint Tokenomics. Users interact with applications through a process called Shifting, whereby XFT is burned to mint synthetics in various protocols, and vice versa.





# II. Introduction: Market Analysis

Offshift Core developed the Offshift Ecosystem in response to four key market trends.

#### 1. The Decade of DeFi

The recent emergence of the DeFi has allowed the crypto space to retain capital and drive further innovation. From decentralized lending and borrowing services to synthetic asset minting, DeFi applications offer users an endless stream of opportunities to leverage the liquidity vested in their otherwise dormant crypto-assets, and of course, to earn yields. Simply put, DeFi allows individuals to earn steady income on their assets without transferring their capital back to traditional financial instruments.

#### 2. Emerging Authoritarian Initiatives

As cryptocurrencies have enjoyed newfound popularity in the mainstream, so too have they drawn increased attention from governments and regulatory agencies. Many authorities have expressed clear intentions to integrate cryptocurrency frameworks into existing financial infrastructure where users can be surveilled and identified via mandatory Know-Your-Client (KYC) implementations. Despite significant resistance, authoritarianism is gaining momentum throughout much of the world, and efforts to surveil, limit, and even censor cryptocurrency transactions are only just beginning to surface.

#### 3. Siloed Privacy Technologies

Many projects and cryptography specialists remain dedicated to the prerogative of personal privacy. However, their most robust privacy solutions comprise standalone blockchains whose native assets confer privacy as an exclusive feature.

#### 4. Infrastructural Limitations

In the mission to produce a robust, private DeFi platform, development teams are hardly to blame. At present, Ethereum and EVM-compatible blockchains simply do not have the infrastructural capacity to support the computationally intensive cryptography required to implement on-chain confidential assets. Even with many iterations of optimization, fitting the necessary cryptographic proofs within Ethereum’s single-block gas limit remains an arduous task. It is for this reason that many purported on-chain private DeFi platforms compromise on decentralization, and instead rely on rollups and other Layer 2 solutions to conduct obfuscation and computation. While many scalability solutions likely lie on the horizon, providing comprehensive on-chain privacy in 2022 might well be likened to sending a high-definition video via email in 1999: application potential is limited by infrastructure capability. In addition to existing infrastructure, prominent DeFi applications are less than prepared to integrate confidential assets, and gas fees involved in smart contract integrations impose limitations on composability.





# III. PriFi and the PriFi Standard

Since its explosion in 2020, the DeFi umbrella has expanded convincingly over the landscape of cryptocurrency, attracting investors and enthusiasts whose preferences speak for themselves: **the systemic benefits of privacy and decentralization are undeniable, but the immediate, individual benefits of yield generation are irresistable.** In the current of ever-expanding trade-offs that individuals must forfeit in order to retain privacy, DeFi yields have finally tipped the scales in favor of public exposure. Nonetheless, there remains substantial, untapped demand in Ethereum’s DeFi ecosystem for an ecosystem that eliminates the financial trad-eoffs between privacy and DeFi.

In the remainder of this paper, we define the Offshift Ecosystem and its native applications as composing an emergent sector called PriFi (Private Decentralized Finance). To earn the PriFi classification, applications and the synthetic assets they generate must adhere to the PriFi Standard by:

1) Supporting truly decentralized financial tools.

2) Conferring robust privacy, anonymity, and/or confidentiality to users and/or assets.

3) Originating and remaining fully on Layer 1.





# IV. Ecosystem Features and Dynamics

Offshift Ecosystem features and dynamics are presented in detail below.



## A. On-Chain Privacy Solutions

PriFi Applications in the Offshift Ecosystem may utilize one or a combination of different privacy-centric technologies in order to confer privacy, anonymity, and/or confidentiality to users and/or assets. Offshift Core will both develop original PriFi Applications and provide relevant research, development resources, and privacy to development teams committed to supplementing the Offshift Ecosystem with additional PriFi Applications. Leading privacy solutions include but are not limited to:

- Zero-knowledge (zk) Proofs

- Differential Privacy

- Anonymizers

- Homomorphic Encryption

- Synthetic Data Generation

- Federated Learning

  

## B. Chainlink Oracles for On-Chain Asset Diversity

In order to support a trustless user experience, Offshift sources accurate price feeds to calculate exchange rates across assets using Chainlink’s industry-leading distributed oracle network. Chainlink oracles provide robust, real time price feeds to support a wide range of synthetics in Offshift Ecosystem PriFi Applications. As such, the Offshift Ecosystem is fully capable of supporting tradeable synthetics that mirror not only cryptocurrencies and fiat currencies, but publicly traded assets, gold, silver, and other commodities as well. In full, the Offshift Ecosystem aims to host the world’s most versatile, privacy-centric, and decentralized financial landscape.

More information on Offshift Core’s collaboration with Chainlink is available in our September 30, 2020 Blog post.[^ref1]



## C. Seamless Shifting to Replace Collateral Management

Unlike other synthetic asset platforms, PriFi Applications in the Offshift Ecosystem do not impose excessive collateral requirements of any kind. Over-collateralization is an outdated mechanism that is not capital-efficient. In addition, collateral pools require custodial services that present attack vectors, whereas Offshift Ecosystem PriFi applications function without dependency on collateral pools or custodianship of any kind.

With Offshift’s signature **Burn-and-Mint Mechanism** and XFT’s elastic supply model, users are afforded a seamless trading experience void of slippage and related liquidity risks. When users burn XFT to mint synthetics, they never have to worry about margin calls, liquidations, or periodic fees to maintain their positions. In reverse, users may burn their synthetics to mint XFT at any time.



## D. Hardcoded Integrity

As an organization in a nascent, decentralized industry, Offshift Core acknowledges and respects the challenges users and community members face in vetting projects for dishonest practice, exploitative tokenomic models, and outright deceit. We further acknowledge that, although the choice of some of our team members to remain anonymous aligns with the broader principles of our organization, we owe it to our community and everyone exploring the Offshift Ecosystem to take all necessary measures to ensure the ethical, high-integrity operation of the platform. In our commitment to integrity, we have employed a strategic vesting model, lockboxes for on-chain reserves (see [VI. C 2](#2.-lockboxes-for-on-chain-reserves)), and liquidity locks (see [VI. C 3](#3.-liquidity-locks)).





# V. Platform Tokenomics: Utility and Incentives

Offshift Ecosystem Tokenomics and Incentives are described in detail below.



## A. Shifting with the Burn-and-Mint Mechanism

To mint synthetics in the Offshift Ecosystem, users select and open a PriFi Application, and connect an ERC20 wallet. If a user possesses a positive XFT balance and sufficient ETH to cover gas fees, he/she may conduct a **Shift** and enter the Offshift Ecosystem’s private (anonymous and/or confidential) side via the Burn-and-Mint Mechanism.

The **Burn-and-Mint Mechanism** burns the user’s XFT and mints one or more synthetics of equal value. At any point, a user may **Shift** back from his/her synthetics into XFT, and the process reverses: the **Burn-and-Mint Mechanism** burns the synthetics, and mints new XFT of equal value to the user’s designated ERC20 wallet address. Such a model enables users to mint, store, and exchange synthetics free from collateral requirements and the margin calls and liquidations that come with them, making for a cost-efficient and stress-free trading experience. It should be noted that although such a tokenomic model demands an elastic supply model for XFT, it does not imply or require any propensity toward long-term inflationary or deflationary monetary attributes.



## B. Reward Incentives: Staking Rewards

In addition to providing technical support and advisory, Offshift Core will support Offshift Ecosystem PriFi Applications with native staking features. Offshift Core has allocated 15% of the Genesis Total Supply (1,500,000 XFT) to its Staking Rewards Wallet (see [VI C 1](#1.-strategic-vesting-model)).





# VI. Fundraising Model & Token Metrics

The Offshift Ecosystem’s Fundraising Model and Token Metrics are presented in detail below.



## A. Capital Raise

Offshift raised capital through one round of seed investment and one round of private investment. In the interests of decentralizing token ownership, individual investment contributions were capped at $5,000 in USD-equivalents in both rounds.



## B. Token Allocations

From  the Genesis Total Supply of 10,000,000 XFT:

- 1,500,000 XFT were sold between the seed and private investment rounds. 

- 250,000 XFT were deployed in the Uniswap liquidity pool. [^fn1]

- 1,750,000 XFT comprised the Circulating Supply as of our August 3, 2020 Uniswap launch.

- The remaining XFT allocations are illustrated in the graphics below.

  

<img align="left" src="001.png">



<img align="left" src="002.png">



## C. High-Integrity Tokenomic Measures

In honor of our commitment to a high-integrity development process, full transparency, and a long-term project vision, we have taken substantial measures to ensure that all token allocations outside of our initial circulating supply will never serve as a source of undue or excessive inflation at any stage in our development lifecycle. Attending to this prerogative, we have taken the following measures:



#### 1. Strategic Vesting Model

We have established gradual, long-term vesting periods for our Marketing/Ecosystem, Development, and Team wallets, as well as for our designated Staking Rewards wallet. Wallet-specific vesting parameters are available below:[^fn2]

- Marketing/Ecosystem (22.5%): 1.25% every 2 months, beginning Oct. 3, 2020

- Development (22.5%): 1.25% every 2 months, beginning Oct. 3, 2020

- Team (20%): 1% every 2 months, beginning Feb. 3, 2021

- Staking Rewards (15%): 0.25% every month, beginning Feb. 3, 2021

  

#### 2. Lockboxes for On-chain Reserves

To ensure that even our core team cannot modify our token metrics or vesting strategy, we have hardcoded our vesting model using Time Lock smart contracts that unlock tokens in tranches congruent with the vesting model described above. 

Source code for the Development/Ecosystem Time Lock contract[^ref2], Marketing Time Lock contract[^ref3], Team Time Lock contract[^ref4] and Staking Rewards Time Lock contract[^ref5] is verified and viewable on Etherscan, and each contract URL is linked in the references section of this document.



#### 3. Liquidity Locks

In addition to our Time Lock contracts for on-chain reserves, we also employ a Time Lock contract for the initial Uniswap liquidity provided by Offshift Core. Source code for the Uniswap LP Token Time Lock contract[^ref6] is verified and viewable on Etherscan, and the contract URL is linked in the references section of this document.



## D. Token Emission Schedule

In accordance with our Vesting Model, the Genesis Total Supply of 10,000,000 XFT will be gradually released into the Circulating Supply over the course of 5 years and 5 months via the following Token Emission Schedule.



<img align="left"  src="003.png">






# VII. Long-term Vision: A Privacy-Centric DeFi Ecosystem

At Offshift Core, our ultimate vision encompasses the formation of a scalable, privacy-centric DeFi ecosystem composed of a diverse range of disruptive platforms and applications. We are pioneers playing a decisive visionary role in the development of cryptocurrency’s next major growth catalyst: the #PriFi landscape.

In the years ahead, we envisage the organic formation of a robust ecosystem whose applications enable users to engage in decentralized lending and borrowing, various forms of yield farming, the formation and exchange of insurance products, NFT generation, and much more – all while remaining fully anonymous, exchanging confidential on-chain assets, and protecting their privacy. XFT will anchor and connect PriFi applications, catalyzing public-private capital flows and acting as a low-friction channel for users entering from and exiting to the public side.





# VIII. Resources

The Offshift team and community are active and can be reached on the following platforms:

- **[Website](https://offshift.io)**
- **[Telegram](https://t.me/OffshiftXFT)**
- **[Twitter](https://twitter.com/OffshiftXFT)**
- **[YouTube](https://youtube.com/c/OffshiftXFT)**
- **[GitLab](https://open.offshift.io)**
- **[Bitcointalk](https://bitcointalk.org/index.php?topic=5262262)**





# IX. Disclaimer

The purchase of XFT tokens involves substantial risk and may lead to partial or complete losses. Purchasers should carefully assess and knowingly accept all relevant risks. XFT tokens should only be purchased after developing a full understanding of the nature and functionality of XFT tokens and the Offshift protocol. Offshift intends to operate within the parameters of the law and is not to be used as part of any regulatory or statutory violation. Any purchase of XFT constitutes an agreement that the purchaser accepts full responsibility for the manner and means of use and relieves Offshift of any civil or criminal liability. 

This whitepaper does not constitute investment advice, legal advice, financial advice, trading advice, or any recommendation of any kind, and Offshift makes no representation that purchasers of XFT can or should expect any profit or return on their purchase based on the efforts of Offshift or a third party. XFT is not a security or any other investment device and should not be treated as such. The development, timeline, and roll-out of the initiatives described in this whitepaper are not guaranteed. DYOR.





---

##### Footnotes

[^fn1]: A total of 500,000 XFT were initially reserved for liquidity provision, but only 250,000 XFT were deployed in the Uniswap liquidity pool. The remaining liquidity reserves of 250,000 XFT remain locked on-chain, and will be allocated appropriated as follows, pending the discretion of the Offshift community: Distributed to platform users in the future as part of an LP rewards program; Burned in their entirety; Some combination of these options.

[^fn2]: All percentage (%) figures express a nominal amount of XFT tokens relative to the Total Genesis Supply of XFT on a percentage basis.



---

##### References

[^ref1]: [Offshift Taps Chainlink to Provide Oracle Feeds](https://offshift.io/public/blog/2020-09-30-offshift-taps-chainlink-to-provide-oracle-feeds-for-its-zkasset-private-pegs/)

[^ref2]: [Development/Ecosystem Time Lock Contract](https://etherscan.io/address/0xcff782dbb92f187aa3df6823c8e690c4f128ef41#code)

[^ref3]: [Marketing Time Lock Contract](https://etherscan.io/address/0x7c06d60ba831ab7fbc95b2ded49610843b02e643#code)

[^ref4]: [Team Time Lock Contract](https://etherscan.io/address/0xf7d71d20fa1aa53c07eb8b1b671ea3553c90ff98#code)

[^ref5]: [Staking Rewards Time Lock Contract](https://etherscan.io/address/0xf7d71d20fa1aa53c07eb8b1b671ea3553c90ff98#code)

[^ref6]: [Uniswap LP Token Time Lock Contract](https://etherscan.io/address/0x136d9c2766665129b5a7cddcc10896598c3f41b6#code)
